==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>完成</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>約束軸...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>在兩個物件之間設置軸約束</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>自我檢測</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>執行自我檢查確認程式是否運作良好</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>&amp;繪圖</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>&amp;素描</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>光跡追踪(&amp;R)</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>製圖(&amp;D)</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>基底草圖</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>元件</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>參數</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>物件顯示</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>線條工具</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>完成</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>約束軸...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>在兩個物件之間設置軸約束</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>自我檢測</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>執行自我檢查確認程式是否運作良好</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>&amp;繪圖</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>&amp;素描</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>光跡追踪(&amp;R)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>製圖(&amp;D)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>基底草圖</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>元件</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">參數</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>物件顯示</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>線條工具</translation>
    </message>
  </context>
</TS>
